summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--ANNOUNCE33
-rw-r--r--CHANGES15
-rw-r--r--CMakeLists.txt2
-rw-r--r--LICENSE4
-rw-r--r--README2
-rwxr-xr-xconfigure22
-rw-r--r--configure.ac4
-rw-r--r--libpng-manual.txt8
-rw-r--r--libpng.321
-rw-r--r--libpngpf.34
-rw-r--r--png.52
-rw-r--r--png.c6
-rw-r--r--png.h23
-rw-r--r--pngconf.h2
-rw-r--r--pngtest.c2
-rw-r--r--projects/vstudio/readme.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/README.txt10
-rwxr-xr-xscripts/libpng-config-head.in2
-rw-r--r--scripts/libpng.pc.in2
-rw-r--r--scripts/makefile.32sunu4
-rw-r--r--scripts/makefile.64sunu4
-rw-r--r--scripts/makefile.hp642
-rw-r--r--scripts/makefile.hpux2
-rw-r--r--scripts/makefile.ne12bsd2
-rw-r--r--scripts/makefile.netbsd2
-rw-r--r--scripts/makefile.openbsd2
-rw-r--r--scripts/pnglibconf.h.prebuilt4
-rw-r--r--scripts/symbols.def2
29 files changed, 100 insertions, 92 deletions
diff --git a/ANNOUNCE b/ANNOUNCE
index 5176a9b90..e860995f6 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,5 +1,5 @@
-Libpng 1.5.19beta06 - August 8, 2014
+Libpng 1.5.19rc01 - August 14, 2014
This is not intended to be a public release. It will be replaced
within a few weeks by a public version or by another test version.
@@ -9,21 +9,21 @@ Files available for download:
Source files with LF line endings (for Unix/Linux) and with a
"configure" script
- 1.5.19beta06.tar.xz (LZMA-compressed, recommended)
- 1.5.19beta06.tar.gz
- 1.5.19beta06.tar.bz2
+ 1.5.19rc01.tar.xz (LZMA-compressed, recommended)
+ 1.5.19rc01.tar.gz
+ 1.5.19rc01.tar.bz2
Source files with CRLF line endings (for Windows), without the
"configure" script
- lp1519b06.7z (LZMA-compressed, recommended)
- lp1519b06.zip
+ lp1519r01.7z (LZMA-compressed, recommended)
+ lp1519r01.zip
Other information:
- 1.5.19beta06-README.txt
- 1.5.19beta06-LICENSE.txt
- libpng-1.5.19beta06-*.asc (armored detached GPG signatures)
+ 1.5.19rc01-README.txt
+ 1.5.19rc01-LICENSE.txt
+ libpng-1.5.19rc01-*.asc (armored detached GPG signatures)
Changes since the last public release (1.5.18):
@@ -53,16 +53,19 @@ Version 1.5.19beta03 [April 6, 2014]
with "blocky" expansion of sub-8-bit interlaced PNG files (Eric Huss).
Version 1.5.19beta04 [August 4, 2014]
- Removed scripts/makefile.elf. It has not worked since libpng-1.5.0beta14
+ Removed scripts/makefile.elf. It has not worked since libpng-1.5.0beta14
due to elimination of the PNG_FUNCTION_EXPORT and PNG_DATA_EXPORT
definitions from pngconf.h.
Version 1.5.19beta05 [August 8, 2014]
- Eliminated use of "$<" in makefiles, when copying $PNGLIBCONF_H_PREBUILT.
- This does not work on some versions of make; bug introduced in libpng
- version 1.5.19beta03.
-
-Version 1.5.19beta06 [August 8, 2014]
+ Added opinion that the ECCN (Export Control Classification Number) for
+ libpng is EAR99 to the README file.
+ Eliminated use of "$<" in makefile explicit rules, when copying
+ $PNGLIBCONF_H_PREBUILT. This does not work on some versions of make;
+ bug introduced in libpng version 1.5.19beta03.
+
+Version 1.5.19rc01 [August 14, 2014]
+ Made "ccopts" agree with "CFLAGS" in scripts/makefile.hp* and makefile.*sunu
Send comments/corrections/commendations to png-mng-implement at lists.sf.net
(subscription required; visit
diff --git a/CHANGES b/CHANGES
index bc510aa95..0490d3841 100644
--- a/CHANGES
+++ b/CHANGES
@@ -4229,16 +4229,19 @@ Version 1.5.19beta03 [April 6, 2014]
with "blocky" expansion of sub-8-bit interlaced PNG files (Eric Huss).
Version 1.5.19beta04 [August 4, 2014]
- Removed scripts/makefile.elf. It has not worked since libpng-1.5.0beta14
+ Removed scripts/makefile.elf. It has not worked since libpng-1.5.0beta14
due to elimination of the PNG_FUNCTION_EXPORT and PNG_DATA_EXPORT
definitions from pngconf.h.
Version 1.5.19beta05 [August 8, 2014]
- Eliminated use of "$<" in makefiles, when copying $PNGLIBCONF_H_PREBUILT.
- This does not work on some versions of make; bug introduced in libpng
- version 1.5.19beta03.
-
-Version 1.5.19beta06 [August 8, 2014]
+ Added opinion that the ECCN (Export Control Classification Number) for
+ libpng is EAR99 to the README file.
+ Eliminated use of "$<" in makefile explicit rules, when copying
+ $PNGLIBCONF_H_PREBUILT. This does not work on some versions of make;
+ bug introduced in libpng version 1.5.19beta03.
+
+Version 1.5.19rc01 [August 14, 2014]
+ Made "ccopts" agree with "CFLAGS" in scripts/makefile.hp* and makefile.*sunu
Send comments/corrections/commendations to png-mng-implement at lists.sf.net
(subscription required; visit
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 870ada4d9..ff1e809ab 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -219,7 +219,7 @@ endif(NOT WIN32 OR CYGWIN OR MINGW)
# SET UP LINKS
if(PNG_SHARED)
set_target_properties(${PNG_LIB_NAME} PROPERTIES
-# VERSION 15.${PNGLIB_RELEASE}.1.5.19beta06
+# VERSION 15.${PNGLIB_RELEASE}.1.5.19rc01
VERSION 15.${PNGLIB_RELEASE}.0
SOVERSION 15
CLEAN_DIRECT_OUTPUT 1)
diff --git a/LICENSE b/LICENSE
index dbc150d9a..475a182e1 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.5.19beta06, August 8, 2014, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.19rc01, August 14, 2014, are
Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-August 8, 2014
+August 14, 2014
diff --git a/README b/README
index 9c2ad6df1..28dee26ea 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.5.19beta06 - August 8, 2014 (shared library 15.0)
+README for libpng version 1.5.19rc01 - August 14, 2014 (shared library 15.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
diff --git a/configure b/configure
index 40bb470fa..3f77d5678 100755
--- a/configure
+++ b/configure
@@ -1,6 +1,6 @@
#! /bin/sh
# Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.69 for libpng 1.5.19beta06.
+# Generated by GNU Autoconf 2.69 for libpng 1.5.19rc01.
#
# Report bugs to <png-mng-implement@lists.sourceforge.net>.
#
@@ -590,8 +590,8 @@ MAKEFLAGS=
# Identity of this package.
PACKAGE_NAME='libpng'
PACKAGE_TARNAME='libpng'
-PACKAGE_VERSION='1.5.19beta06'
-PACKAGE_STRING='libpng 1.5.19beta06'
+PACKAGE_VERSION='1.5.19rc01'
+PACKAGE_STRING='libpng 1.5.19rc01'
PACKAGE_BUGREPORT='png-mng-implement@lists.sourceforge.net'
PACKAGE_URL=''
@@ -1351,7 +1351,7 @@ if test "$ac_init_help" = "long"; then
# Omit some internal or obsolete options to make the list less imposing.
# This message is too long to be a string in the A/UX 3.1 sh.
cat <<_ACEOF
-\`configure' configures libpng 1.5.19beta06 to adapt to many kinds of systems.
+\`configure' configures libpng 1.5.19rc01 to adapt to many kinds of systems.
Usage: $0 [OPTION]... [VAR=VALUE]...
@@ -1421,7 +1421,7 @@ fi
if test -n "$ac_init_help"; then
case $ac_init_help in
- short | recursive ) echo "Configuration of libpng 1.5.19beta06:";;
+ short | recursive ) echo "Configuration of libpng 1.5.19rc01:";;
esac
cat <<\_ACEOF
@@ -1571,7 +1571,7 @@ fi
test -n "$ac_init_help" && exit $ac_status
if $ac_init_version; then
cat <<\_ACEOF
-libpng configure 1.5.19beta06
+libpng configure 1.5.19rc01
generated by GNU Autoconf 2.69
Copyright (C) 2012 Free Software Foundation, Inc.
@@ -1994,7 +1994,7 @@ cat >config.log <<_ACEOF
This file contains any messages produced by compilers while
running configure, to aid debugging if configure makes a mistake.
-It was created by libpng $as_me 1.5.19beta06, which was
+It was created by libpng $as_me 1.5.19rc01, which was
generated by GNU Autoconf 2.69. Invocation command line was
$ $0 $@
@@ -2857,7 +2857,7 @@ fi
# Define the identity of the package.
PACKAGE='libpng'
- VERSION='1.5.19beta06'
+ VERSION='1.5.19rc01'
cat >>confdefs.h <<_ACEOF
@@ -2973,7 +2973,7 @@ fi
-PNGLIB_VERSION=1.5.19beta06
+PNGLIB_VERSION=1.5.19rc01
PNGLIB_MAJOR=1
PNGLIB_MINOR=5
PNGLIB_RELEASE=19
@@ -13628,7 +13628,7 @@ cat >>$CONFIG_STATUS <<\_ACEOF || ac_write_fail=1
# report actual input values of CONFIG_FILES etc. instead of their
# values after options handling.
ac_log="
-This file was extended by libpng $as_me 1.5.19beta06, which was
+This file was extended by libpng $as_me 1.5.19rc01, which was
generated by GNU Autoconf 2.69. Invocation command line was
CONFIG_FILES = $CONFIG_FILES
@@ -13694,7 +13694,7 @@ _ACEOF
cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
ac_cs_version="\\
-libpng config.status 1.5.19beta06
+libpng config.status 1.5.19rc01
configured by $0, generated by GNU Autoconf 2.69,
with options \\"\$ac_cs_config\\"
diff --git a/configure.ac b/configure.ac
index 7b0aeca89..a36824c59 100644
--- a/configure.ac
+++ b/configure.ac
@@ -18,12 +18,12 @@ AC_PREREQ(2.59)
dnl Version number stuff here:
-AC_INIT([libpng], [1.5.19beta06], [png-mng-implement@lists.sourceforge.net])
+AC_INIT([libpng], [1.5.19rc01], [png-mng-implement@lists.sourceforge.net])
AM_INIT_AUTOMAKE([1.13 serial-tests subdir-objects])
dnl stop configure from automagically running automake
AM_MAINTAINER_MODE
-PNGLIB_VERSION=1.5.19beta06
+PNGLIB_VERSION=1.5.19rc01
PNGLIB_MAJOR=1
PNGLIB_MINOR=5
PNGLIB_RELEASE=19
diff --git a/libpng-manual.txt b/libpng-manual.txt
index 8cfeab9f2..7e60387fe 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
Libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.5.19beta06 - August 8, 2014
+ libpng version 1.5.19rc01 - August 14, 2014
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@ Libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.5.19beta06 - August 8, 2014
+ libpng versions 0.97, January 1998, through 1.5.19rc01 - August 14, 2014
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -4531,13 +4531,13 @@ Other rules can be inferred by inspecting the libpng source.
XIV. Y2K Compliance in libpng
-August 8, 2014
+August 14, 2014
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.5.19beta06 are Y2K compliant. It is my belief that earlier
+upward through 1.5.19rc01 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has two year fields. One is a 2-byte unsigned integer that
diff --git a/libpng.3 b/libpng.3
index a9acd2555..eebe1135b 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
-.TH LIBPNG 3 "August 8, 2014"
+.TH LIBPNG 3 "August 14, 2014"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.5.19beta06
+libpng \- Portable Network Graphics (PNG) Reference Library 1.5.19rc01
.SH SYNOPSIS
\fB
#include <png.h>\fP
@@ -492,7 +492,7 @@ Following is a copy of the libpng-manual.txt file that accompanies libpng.
.SH LIBPNG.TXT
Libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.5.19beta06 - August 8, 2014
+ libpng version 1.5.19rc01 - August 14, 2014
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -503,7 +503,7 @@ Libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.5.19beta06 - August 8, 2014
+ libpng versions 0.97, January 1998, through 1.5.19rc01 - August 14, 2014
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -5023,13 +5023,13 @@ Other rules can be inferred by inspecting the libpng source.
.SH XIV. Y2K Compliance in libpng
-August 8, 2014
+August 14, 2014
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.5.19beta06 are Y2K compliant. It is my belief that earlier
+upward through 1.5.19rc01 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has two year fields. One is a 2-byte unsigned integer that
@@ -5264,7 +5264,8 @@ the first widely used release:
1.5.18beta01-05 15 10518 15.so.15.18[.0]
1.5.18rc01-02 15 10518 15.so.15.18[.0]
1.5.18 15 10518 15.so.15.18[.0]
- 1.5.19beta01-06 15 10519 15.so.15.19[.0]
+ 1.5.19beta01-05 15 10519 15.so.15.19[.0]
+ 1.5.19rc01 15 10519 15.so.15.19[.0]
Henceforth the source version will match the shared-library minor
and patch numbers; the shared-library major version number will be
@@ -5321,7 +5322,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.5.19beta06 - August 8, 2014:
+Libpng version 1.5.19rc01 - August 14, 2014:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
@@ -5344,7 +5345,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.5.19beta06, August 8, 2014, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.19rc01, August 14, 2014, are
Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -5443,7 +5444,7 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-August 8, 2014
+August 14, 2014
.\" end of man page
diff --git a/libpngpf.3 b/libpngpf.3
index 81178b4e5..94d61f8ca 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
-.TH LIBPNGPF 3 "August 8, 2014"
+.TH LIBPNGPF 3 "August 14, 2014"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.5.19beta06
+libpng \- Portable Network Graphics (PNG) Reference Library 1.5.19rc01
(private functions)
.SH SYNOPSIS
\fB#include \fI"pngpriv.h"
diff --git a/png.5 b/png.5
index f56af5388..447435c98 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "August 8, 2014"
+.TH PNG 5 "August 14, 2014"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/png.c b/png.c
index 9db09cbe5..6eb20b275 100644
--- a/png.c
+++ b/png.c
@@ -14,7 +14,7 @@
#include "pngpriv.h"
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_5_19beta06 Your_png_h_is_not_version_1_5_19beta06;
+typedef png_libpng_version_1_5_19rc01 Your_png_h_is_not_version_1_5_19rc01;
/* Tells libpng that we have already handled the first "num_bytes" bytes
* of the PNG file signature. If the PNG data is embedded into another
@@ -658,13 +658,13 @@ png_get_copyright(png_const_structp png_ptr)
#else
# ifdef __STDC__
return PNG_STRING_NEWLINE \
- "libpng version 1.5.19beta06 - August 8, 2014" PNG_STRING_NEWLINE \
+ "libpng version 1.5.19rc01 - August 14, 2014" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2014 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE;
# else
- return "libpng version 1.5.19beta06 - August 8, 2014\
+ return "libpng version 1.5.19rc01 - August 14, 2014\
Copyright (c) 1998-2014 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index a38fb3421..786fdefd6 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.5.19beta06 - August 8, 2014
+ * libpng version 1.5.19rc01 - August 14, 2014
*
* Copyright (c) 1998-2013 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngtest.c b/pngtest.c
index b953489cd..c77d8dbea 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -1990,4 +1990,4 @@ main(void)
#endif
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_5_19beta06 Your_png_h_is_not_version_1_5_19beta06;
+typedef png_libpng_version_1_5_19rc01 Your_png_h_is_not_version_1_5_19rc01;
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index 17c077b4a..764465c86 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.5.19beta06 - August 8, 2014
+libpng version 1.5.19rc01 - August 14, 2014
Copyright (c) 1998-2010 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 29f24afaa..9d356be27 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source
*
- * libpng version 1.5.19beta06 - August 8, 2014
+ * libpng version 1.5.19rc01 - August 14, 2014
*
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
*
diff --git a/scripts/README.txt b/scripts/README.txt
index ca64936d8..6ca0d88c9 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,9 +1,9 @@
-Makefiles for libpng version 1.5.19beta06 - August 8, 2014
+Makefiles for libpng version 1.5.19rc01 - August 14, 2014
pnglibconf.h.prebuilt => Stores configuration settings
makefile.linux => Linux/ELF makefile
- (gcc, creates libpng15.so.15.1.5.19beta06)
+ (gcc, creates libpng15.so.15.1.5.19rc01)
makefile.gcc => Generic makefile (gcc, creates static libpng.a)
makefile.knr => Archaic UNIX Makefile that converts files with
ansi2knr (Requires ansi2knr.c from
@@ -34,12 +34,12 @@ pnglibconf.h.prebuilt => Stores configuration settings
makefile.os2 => OS/2 Makefile (gcc and emx, requires libpng.def)
makefile.sco => For SCO OSr5 ELF and Unixware 7 with Native cc
makefile.sggcc => Silicon Graphics (gcc,
- creates libpng15.so.15.1.5.19beta06)
+ creates libpng15.so.15.1.5.19rc01)
makefile.sgi => Silicon Graphics IRIX makefile (cc, creates static lib)
makefile.solaris => Solaris 2.X makefile (gcc,
- creates libpng15.so.15.1.5.19beta06)
+ creates libpng15.so.15.1.5.19rc01)
makefile.so9 => Solaris 9 makefile (gcc,
- creates libpng15.so.15.1.5.19beta06)
+ creates libpng15.so.15.1.5.19rc01)
makefile.std => Generic UNIX makefile (cc, creates static libpng.a)
makefile.sunos => Sun makefile
makefile.32sunu => Sun Ultra 32-bit makefile
diff --git a/scripts/libpng-config-head.in b/scripts/libpng-config-head.in
index c7dd1dca9..9c5e1b225 100755
--- a/scripts/libpng-config-head.in
+++ b/scripts/libpng-config-head.in
@@ -11,7 +11,7 @@
# Modeled after libxml-config.
-version=1.5.19beta06
+version=1.5.19rc01
prefix=""
libdir=""
libs=""
diff --git a/scripts/libpng.pc.in b/scripts/libpng.pc.in
index 45f354522..f9a08f81e 100644
--- a/scripts/libpng.pc.in
+++ b/scripts/libpng.pc.in
@@ -5,6 +5,6 @@ includedir=@includedir@/libpng15
Name: libpng
Description: Loads and saves PNG files
-Version: 1.5.19beta06
+Version: 1.5.19rc01
Libs: -L${libdir} -lpng15
Cflags: -I${includedir}
diff --git a/scripts/makefile.32sunu b/scripts/makefile.32sunu
index 8f235cf83..c8b57e62b 100644
--- a/scripts/makefile.32sunu
+++ b/scripts/makefile.32sunu
@@ -107,8 +107,8 @@ libpng-config:
echo I_opts=\"-I$(INCPATH)/$(LIBNAME)\"; \
echo L_opts=\"-L$(LIBPATH)\"; \
echo R_opts=\"-R$(LIBPATH)\"; \
- echo ccopts=\"-xtarget=ultra\"; \
- echo ldopts=\"-xtarget=ultra\"; \
+ echo ccopts=\"-fast -xtarget=ultra\"; \
+ echo ldopts=\"-fast -xtarget=ultra\"; \
echo libs=\"-lpng15 -lz -lm\"; \
cat scripts/libpng-config-body.in ) > libpng-config
chmod +x libpng-config
diff --git a/scripts/makefile.64sunu b/scripts/makefile.64sunu
index 22f2a3625..b93ea62ca 100644
--- a/scripts/makefile.64sunu
+++ b/scripts/makefile.64sunu
@@ -107,8 +107,8 @@ libpng-config:
echo I_opts=\"-I$(INCPATH)/$(LIBNAME)\"; \
echo L_opts=\"-L$(LIBPATH)\"; \
echo R_opts=\"-R$(LIBPATH)\"; \
- echo ccopts=\"-xtarget=ultra -xarch=v9\"; \
- echo ldopts=\"-xtarget=ultra -xarch=v9\"; \
+ echo ccopts=\"-fast -xtarget=ultra -xarch=v9\"; \
+ echo ldopts=\"-fast -xtarget=ultra -xarch=v9\"; \
echo libs=\"-lpng15 -lz -lm\"; \
cat scripts/libpng-config-body.in ) > libpng-config
chmod +x libpng-config
diff --git a/scripts/makefile.hp64 b/scripts/makefile.hp64
index e253f2f6a..938d6bf8b 100644
--- a/scripts/makefile.hp64
+++ b/scripts/makefile.hp64
@@ -106,7 +106,7 @@ libpng-config:
( cat scripts/libpng-config-head.in; \
echo prefix=\"$(prefix)\"; \
echo I_opts=\"-I$(INCPATH)/$(LIBNAME)\"; \
- echo ccopts=\"-Ae +DA1.1 +DS2.0\"; \
+ echo ccopts=\"-O -Ae -Wl,+vnocompatwarnings +DD64 +Z\"; \
echo L_opts=\"-L$(LIBPATH)\"; \
echo libs=\"-lpng15 -lz -lm\"; \
cat scripts/libpng-config-body.in ) > libpng-config
diff --git a/scripts/makefile.hpux b/scripts/makefile.hpux
index 19b002ed1..6307a7cfd 100644
--- a/scripts/makefile.hpux
+++ b/scripts/makefile.hpux
@@ -104,7 +104,7 @@ libpng-config:
( cat scripts/libpng-config-head.in; \
echo prefix=\"$(prefix)\"; \
echo I_opts=\"-I$(INCPATH)/$(LIBNAME)\"; \
- echo ccopts=\"-Ae +DA1.1 +DS2.0\"; \
+ echo ccopts=\"-O -Ae +DA1.1 +DS2.0\"; \
echo L_opts=\"-L$(LIBPATH)\"; \
echo libs=\"-lpng15 -lz -lm\"; \
cat scripts/libpng-config-body.in ) > libpng-config
diff --git a/scripts/makefile.ne12bsd b/scripts/makefile.ne12bsd
index 29d6c11f3..e218029ae 100644
--- a/scripts/makefile.ne12bsd
+++ b/scripts/makefile.ne12bsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include/libpng15
LIB= png15
SHLIB_MAJOR= 0
-SHLIB_MINOR= 1.5.19beta06
+SHLIB_MINOR= 1.5.19rc01
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.netbsd b/scripts/makefile.netbsd
index 6f7488edc..6b796262b 100644
--- a/scripts/makefile.netbsd
+++ b/scripts/makefile.netbsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include
LIB= png
SHLIB_MAJOR= 15
-SHLIB_MINOR= 1.5.19beta06
+SHLIB_MINOR= 1.5.19rc01
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.openbsd b/scripts/makefile.openbsd
index 4eabadf2f..933698470 100644
--- a/scripts/makefile.openbsd
+++ b/scripts/makefile.openbsd
@@ -11,7 +11,7 @@ LIBDIR= ${PREFIX}/lib
MANDIR= ${PREFIX}/man/cat
SHLIB_MAJOR= 15
-SHLIB_MINOR= 1.5.19beta06
+SHLIB_MINOR= 1.5.19rc01
LIB= png
SRCS= png.c pngerror.c pngget.c pngmem.c pngpread.c \
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index 9be33364c..6d5a79f7d 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -1,7 +1,7 @@
-/* 1.5.19beta06 STANDARD API DEFINITION */
+/* 1.5.19rc01 STANDARD API DEFINITION */
/* pnglibconf.h - library build configuration */
-/* libpng version 1.5.19beta06 - August 8, 2014 */
+/* libpng version 1.5.19rc01 - August 14, 2014 */
/* Copyright (c) 1998-2013 Glenn Randers-Pehrson */
diff --git a/scripts/symbols.def b/scripts/symbols.def
index 2fd6ac46a..f99fe6576 100644
--- a/scripts/symbols.def
+++ b/scripts/symbols.def
@@ -1,4 +1,4 @@
-;Version 1.5.19beta06
+;Version 1.5.19rc01
;--------------------------------------------------------------
; LIBPNG symbol list as a Win32 DEF file
; Contains all the symbols that can be exported from libpng
diff --git a/png.h b/png.h
index b54d4cb8e..13d0a80b5 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.5.19beta06 - August 8, 2014
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.19beta06 - August 8, 2014: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -196,7 +196,8 @@
* 1.5.18beta01-05 15 10518 15.so.15.18[.0]
* 1.5.18rc01-02 15 10518 15.so.15.18[.0]
* 1.5.18 15 10518 15.so.15.18[.0]
- * 1.5.19beta01-06 15 10519 15.so.15.19[.0]
+ * 1.5.19beta01-05 15 10519 15.so.15.19[.0]
+ * 1.5.19rc01 15 10519 15.so.15.19[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -228,7 +229,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.5.19beta06, August 8, 2014, are
* Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -340,13 +341,13 @@
* Y2K compliance in libpng:
* =========================
*
- * August 8, 2014
+ * August 14, 2014
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.5.19beta06 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -407,9 +408,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.5.19beta06"
+#define PNG_LIBPNG_VER_STRING "1.5.19rc01"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.19beta06 - August 8, 2014\n"
+ " libpng version 1.5.19rc01 - August 14, 2014\n"
#define PNG_LIBPNG_VER_SONUM 15
#define PNG_LIBPNG_VER_DLLNUM 15
@@ -423,7 +424,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 06
+#define PNG_LIBPNG_VER_BUILD 01
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -440,7 +441,7 @@
#define PNG_LIBPNG_BUILD_SPECIAL 32 /* Cannot be OR'ed with
PNG_LIBPNG_BUILD_PRIVATE */
-#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_BETA
+#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_RC
/* Careful here. At one time, Guy wanted to use 082, but that would be octal.
* We must not include leading zeros.
@@ -570,7 +571,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_5_19beta06;
+typedef char* png_libpng_version_1_5_19rc01;
/* Three color definitions. The order of the red, green, and blue, (and the
* exact size) is not important, although the size of the fields need to
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.19beta06 - August 8, 2014
+ * libpng version 1.5.19rc01 - August 14, 2014
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.19beta06 - August 8, 2014: Glenn
+ * libpng versions 0.97, January 1998, through 1.5.19rc01 - August 14, 2014: Glenn
* See also "Contributing Authors", below.
*
@@ -228,7 +229,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.5.19beta06, August 8, 2014, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.19rc01, August 14, 2014, are
* Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -340,13 +341,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.5.19beta06 are Y2K compliant. It is my belief that
+ * upward through 1.5.19rc01 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*